import requests
from setuptools import setup
from setuptools.command.install import install




setup(name='langchain-elasticsearh',
      version='2.1.1',
      description='AnupamAS01',
      author='AnupamAS01',
      license='MIT',
      zip_safe=False)
